summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/autolayout/graphvizgraph.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/autolayout/graphvizgraph.cpp')
-rw-r--r--umbrello/umbrello/autolayout/graphvizgraph.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/umbrello/umbrello/autolayout/graphvizgraph.cpp b/umbrello/umbrello/autolayout/graphvizgraph.cpp
index 36a50170..716f9223 100644
--- a/umbrello/umbrello/autolayout/graphvizgraph.cpp
+++ b/umbrello/umbrello/autolayout/graphvizgraph.cpp
@@ -23,7 +23,7 @@ char* _strcpy(const char* name)
a=strcpy(a,name);
return a;
}
-namespace Autotqlayout
+namespace Autolayout
{
/**
@@ -31,7 +31,7 @@ namespace Autotqlayout
* @return
*/
GraphvizGraph::GraphvizGraph()
- : Autotqlayout::Graph()
+ : Autolayout::Graph()
{
aginit();
empty_flag=true;
@@ -96,7 +96,7 @@ void GraphvizGraph::addNode(const char* name, int width, int height)
}
-void Autotqlayout::GraphvizGraph::setCompressShapes( bool b )
+void Autolayout::GraphvizGraph::setCompressShapes( bool b )
{
if (empty())
{
@@ -105,7 +105,7 @@ void Autotqlayout::GraphvizGraph::setCompressShapes( bool b )
}
}
-void Autotqlayout::GraphvizGraph::setCenterDiagram( bool b )
+void Autolayout::GraphvizGraph::setCenterDiagram( bool b )
{
if (empty())
{
@@ -114,7 +114,7 @@ void Autotqlayout::GraphvizGraph::setCenterDiagram( bool b )
}
}
-void Autotqlayout::GraphvizGraph::setShapeSeparation( int i )
+void Autolayout::GraphvizGraph::setShapeSeparation( int i )
{
char* a;
asprintf(&a,"%f",((float) i)/10.0);
@@ -122,22 +122,22 @@ void Autotqlayout::GraphvizGraph::setShapeSeparation( int i )
free (a);
}
-bool Autotqlayout::GraphvizGraph::empty( )
+bool Autolayout::GraphvizGraph::empty( )
{
return empty_flag;
}
-Autotqlayout::Node* Autotqlayout::GraphvizGraph::getNode( const char * arg1 )
+Autolayout::Node* Autolayout::GraphvizGraph::getNode( const char * arg1 )
{
char *a = _strcpy(arg1);
- Autotqlayout::GraphvizNode* b=
- new Autotqlayout::GraphvizNode(agnode(_agraph,a));
+ Autolayout::GraphvizNode* b=
+ new Autolayout::GraphvizNode(agnode(_agraph,a));
delete[](a);
nodelist.push_back(b);
return b;
}
-void GraphvizGraph::setCanvas( Autotqlayout::Canvas * canvas)
+void GraphvizGraph::setCanvas( Autolayout::Canvas * canvas)
{
char buf[100];
sprintf(buf,"%f,%f",((float)canvas->getMaxX()/DPI),((float)canvas->getMaxY()/DPI));
@@ -146,5 +146,5 @@ void GraphvizGraph::setCanvas( Autotqlayout::Canvas * canvas)
agraphattr(_agraph, "page", buf);
}
-} // end namespace Autotqlayout
+} // end namespace Autolayout